@@ -1,8 +1,8 @@
 /**************************************************************************
 **       Title: display video from multiple cameras/multiple cards
 **    $RCSfile: dc1394_multiview.c,v $
-**   $Revision: 1.9 $$Name:  $
-**       $Date: 2004/08/10 07:57:22 $
+**   $Revision: 1.11 $$Name:  $
+**       $Date: 2005/12/21 11:22:49 $
 **   Copyright: LGPL $Author: ddouxchamps $
 ** Description:
 **
@@ -15,6 +15,12 @@
 **-------------------------------------------------------------------------
 **
 **  $Log: dc1394_multiview.c,v $
+**  Revision 1.11  2005/12/21 11:22:49  ddouxchamps
+**  Fixed compilation warning and a bug in camera detection
+**
+**  Revision 1.10  2005/08/18 07:03:06  ddouxchamps
+**  I looked at the bug reports on SF and applied some fixes
+**
 **  Revision 1.9  2004/08/10 07:57:22  ddouxchamps
 **  Removed extra buffering (Johann Schoonees)
 **
@@ -280,7 +286,7 @@ void display_frames()
 			}
 		}
 		
-		xv_image=XvCreateImage(display,info[adaptor].base_id,format,frame_buffer,
+		xv_image=XvCreateImage(display,info[adaptor].base_id,format, (char*)frame_buffer,
 			device_width,device_height * numCameras);
 		XvPutImage(display,info[adaptor].base_id,window,gc,xv_image,
 			0,0,device_width,device_height * numCameras,
@@ -298,7 +304,7 @@ void QueryXv()
 	int i,j;
 	char xv_name[5];
 	
-	XvQueryAdaptors(display,DefaultRootWindow(display),&num_adaptors,&info);
+	XvQueryAdaptors(display,DefaultRootWindow(display),(unsigned int*)&num_adaptors,&info);
 	
 	for(i=0;i<num_adaptors;i++) {
 		formats=XvListImageFormats(display,info[i].base_id,&num_formats);
@@ -402,10 +408,9 @@ int main(int argc,char *argv[])
 		int camCount;
 		
 		/* get the camera nodes and describe them as we find them */
-		raw_handle = raw1394_new_handle();
-		raw1394_set_port( raw_handle, p );
+		raw_handle=dc1394_create_handle(p);
 		camera_nodes = dc1394_get_camera_nodes(raw_handle, &camCount, 1);
-		raw1394_destroy_handle(raw_handle);
+		dc1394_destroy_handle(raw_handle);
 
 		/* setup cameras for capture */
 		for (i = 0; i < camCount; i++)
