@@ -346,8 +346,8 @@ _dc1394_dma_basic_setup(int channel,
 **************************************************************/
 int 
 dc1394_setup_capture(raw1394handle_t handle, nodeid_t node, 
-                     int channel, int format, int mode, 
-                     int speed, int frame_rate, 
+                     unsigned int channel, unsigned int format, unsigned int mode, 
+                     unsigned int speed, unsigned int frame_rate, 
                      dc1394_cameracapture * camera) 
 {
   if( format == FORMAT_SCALABLE_IMAGE_SIZE)
@@ -459,11 +459,12 @@ dc1394_multi_capture(raw1394handle_t handle, dc1394_cameracapture *cams,
         _dc1394_quadlets_per_packet[cams[i].channel]=
             cams[i].quadlets_per_packet;
 
+	//fprintf(stderr,"starting reception...\n");
         if (raw1394_start_iso_rcv(handle,cams[i].channel) < 0) 
         {
             /* error handling- for some reason something didn't work, 
                so we have to reset everything....*/
-            printf("(%s:%d) error!\n", __FILE__, __LINE__);
+            fprintf(stderr,"(%s:%d) error!\n", __FILE__, __LINE__);
 
             for (j= 0; j < num; j++) 
             {
@@ -475,10 +476,12 @@ dc1394_multi_capture(raw1394handle_t handle, dc1394_cameracapture *cams,
         }
 
     }
+    //fprintf(stderr,"data loop...\n");
 
     /* now we iterate till the data is here*/
     while (_dc1394_all_captured != 0) 
     {
+      //fprintf(stderr,"iter ");
         raw1394_loop_iterate(handle);
     }
   
@@ -508,8 +511,8 @@ dc1394_multi_capture(raw1394handle_t handle, dc1394_cameracapture *cams,
 ******************************************************/
 int
 dc1394_dma_setup_capture(raw1394handle_t handle, nodeid_t node,
-                         int channel, int format, int mode,
-                         int speed, int frame_rate,
+                         unsigned int channel, unsigned int format, unsigned int mode,
+                         unsigned int speed, unsigned int frame_rate,
                          int num_dma_buffers, 
 			 int drop_frames,
 			 const char *dma_device_file,
@@ -578,6 +581,8 @@ dc1394_dma_release_camera(raw1394handle_t handle,
 	  }
     }
 
+    free(camera->dma_device_file);
+
     return DC1394_SUCCESS;
 }
 
