@@ -194,6 +194,9 @@ const char *dc1394_feature_desc[NUM_FEATURES] =
     "Focus",
     "Temperature",
     "Trigger",
+    "Trigger Delay",
+    "White Shading",
+    "Frame Rate",
     "Zoom",
     "Pan",
     "Tilt",
@@ -493,8 +496,9 @@ GetCameraROMValue(raw1394handle_t handle, nodeid_t node,
     /* retry a few times if necessary (addition by PDJ) */
     while(retry--) 
     {
-        retval= raw1394_read(handle, 0xffc0 | node, CONFIG_ROM_BASE + offset,
-                             4, value);
+      //fprintf(stderr,"get reg at 0x%llx : ", CONFIG_ROM_BASE + offset);
+      retval= raw1394_read(handle, 0xffc0 | node, CONFIG_ROM_BASE + offset, 4, value);
+      //fprintf(stderr,"0x%lx\n",*value);
 
 #ifdef LIBRAW1394_OLD
         if (retval >= 0)
@@ -544,20 +548,22 @@ GetCameraControlRegister(raw1394handle_t handle, nodeid_t node,
     camera = (dc1394_camerahandle*) raw1394_get_userdata( handle );
 
     /* get the ccr_base address if not yet retrieved */
-    if (camera != NULL && camera->ccr_base == 0)
-    {
+    if (camera != NULL) {
+      if (camera->ccr_base == 0) {
         dc1394_camerainfo info;
         if ( dc1394_get_camera_info(handle, node, &info) != DC1394_SUCCESS )
-            return -1;
+	  return -1;
+      }
     }
-    else if (camera == NULL)
-        return -1;
+    else
+      return -1;
 
     /* retry a few times if necessary (addition by PDJ) */
     while(retry--) 
     {
-        retval= raw1394_read(handle, 0xffc0 | node, camera->ccr_base + offset,
-                             4, value);
+      //fprintf(stderr,"get reg at 0x%llx : ", camera->ccr_base+offset);
+      retval= raw1394_read(handle, 0xffc0 | node, camera->ccr_base + offset, 4, value);
+      //fprintf(stderr,"0x%lx\n",*value);
 
 #ifdef LIBRAW1394_OLD
         if (retval >= 0)
@@ -607,14 +613,15 @@ SetCameraControlRegister(raw1394handle_t handle, nodeid_t node,
     camera = (dc1394_camerahandle*) raw1394_get_userdata( handle );
 
     /* get the ccr_base address if not yet retrieved */
-    if (camera != NULL && camera->ccr_base == 0)
-    {
+    if (camera != NULL) {
+      if (camera->ccr_base == 0) {
         dc1394_camerainfo info;
         if ( dc1394_get_camera_info(handle, node, &info) != DC1394_SUCCESS )
-            return -1;
+	  return -1;
+      }
     }
-    else if (camera == NULL)
-        return -1;
+    else
+      return -1;
 
     /* conditionally byte swap the value (addition by PDJ) */
     value= htonl(value);
@@ -657,6 +664,137 @@ SetCameraControlRegister(raw1394handle_t handle, nodeid_t node,
     return retval;
 }
 
+/********************************************************************************/
+/* Get Advanced Features Registers                                              */
+/********************************************************************************/
+int
+GetCameraAdvControlRegister(raw1394handle_t handle, nodeid_t node,
+                         octlet_t offset, quadlet_t *value)
+{
+    int retval, retry= MAX_RETRIES;
+    dc1394_camerahandle *camera;
+    quadlet_t adv_temp;
+    
+    camera = (dc1394_camerahandle*) raw1394_get_userdata( handle );
+    
+     
+    if(!camera->adv_csr)
+    {
+      if(GetCameraControlRegister(handle, node,REG_CAMERA_ADV_FEATURE_INQ, &adv_temp))
+ return -1;
+
+      camera->adv_csr= adv_temp*4 + CONFIG_ROM_BASE;
+    }
+
+    /* retry a few times if necessary (addition by PDJ) */
+    while(retry--) 
+    {
+        retval= raw1394_read(handle, 0xffc0 | node, camera->adv_csr + offset,
+                             4, value);
+
+/*        printf(" Get Adv debug : base = %Lux, offset = %Lux, base + offset = %Lux\n",camera->adv_csr,offset, camera->adv_csr+offset);*/
+
+#ifdef LIBRAW1394_OLD
+        if (retval >= 0)
+        {
+            int ack= retval >> 16;
+            int rcode= retval & 0xffff;
+
+#ifdef SHOW_ERRORS
+            printf("CCR read ack of %x rcode of %x\n", ack, rcode);
+#endif
+
+            if ( ((ack == ACK_PENDING) || (ack == ACK_LOCAL)) &&
+                 (rcode == RESP_COMPLETE) )
+            { 
+                /* conditionally byte swap the value */
+                *value= ntohl(*value); 
+                return 0;
+            }
+
+        }
+#else
+        if (!retval)
+        {
+            /* conditionally byte swap the value (addition by PDJ) */
+            *value= ntohl(*value);  
+            return retval; 
+        }
+        else if (errno != EAGAIN)
+        {
+            return retval;
+        }
+#endif /* LIBRAW1394_VERSION <= 0.8.2 */
+
+        usleep(SLOW_DOWN);
+    }
+    
+    *value= ntohl(*value);
+    return retval;
+}
+
+
+/********************************************************************************/
+/* Set Advanced Features Registers                                              */
+/********************************************************************************/
+int
+SetCameraAdvControlRegister(raw1394handle_t handle, nodeid_t node,
+                         octlet_t offset, quadlet_t value)
+{
+    int retval, retry= MAX_RETRIES;
+    dc1394_camerahandle *camera;
+    quadlet_t adv_temp;
+    
+    camera = (dc1394_camerahandle*) raw1394_get_userdata( handle );
+    
+    if(!camera->adv_csr)
+    {
+      if(GetCameraControlRegister(handle, node,REG_CAMERA_ADV_FEATURE_INQ, &adv_temp))
+ return -1;
+
+      camera->adv_csr= adv_temp*4 + CONFIG_ROM_BASE;
+    }
+
+    /* conditionally byte swap the value (addition by PDJ) */
+    value= htonl(value);
+
+    /* retry a few times if necessary */
+    while(retry--)
+    {
+        retval= raw1394_write(handle, 0xffc0 | node, camera->adv_csr + offset, 4,
+                              &value);
+/*        printf(" Set Adv debug : base = %Lux, offset = %Lux, base + offset = %Lux\n",camera->adv_csr,offset, camera->adv_csr+offset); */
+#ifdef LIBRAW1394_OLD
+        if (retval >= 0)
+        {
+            int ack= retval >> 16;
+            int rcode= retval & 0xffff;
+
+#ifdef SHOW_ERRORS
+            printf("CCR write ack of %x rcode of %x\n", ack, rcode);
+#endif
+
+            if ( ((ack == ACK_PENDING) || (ack == ACK_LOCAL) ||
+                  (ack == ACK_COMPLETE)) &&
+                 ((rcode == RESP_COMPLETE) || (rcode == RESP_SONY_HACK)) ) 
+            {
+                return 0;
+            }
+            
+        }
+#else
+        if (!retval || (errno != EAGAIN))
+        {
+            return retval;
+        }
+#endif /* LIBRAW1394_VERSION <= 0.8.2 */
+
+        usleep(SLOW_DOWN);
+    }
+
+    return retval;
+}
+
 static int
 IsFeatureBitSet(quadlet_t value, unsigned int feature)
 {
@@ -838,7 +976,7 @@ dc1394_get_camera_nodes(raw1394handle_t handle, int *numCameras,
 nodeid_t* 
 dc1394_get_sorted_camera_nodes(raw1394handle_t handle,int numIds, 
                                int *ids, int *numCameras,
-                               int showCameras) 
+                              int showCameras) 
 {
     int numNodes, i,j, uid, foundId, extraId;
     dc1394bool_t isCamera;
@@ -1019,30 +1157,18 @@ dc1394_is_camera(raw1394handle_t handle, nodeid_t node, dc1394bool_t *value)
         return DC1394_SUCCESS;
     }
 
-    quadval = 0;
+    int version;
     /* get the unit_sw_version (should be 0x000100 - 0x000102 for 1394 digital camera) */
     /* DRD> without this check, AV/C cameras show up as well */
-    offset = ud_offset;
-    if (GetConfigROMTaggedRegister(handle, node, 0x13, &offset, &quadval)!=DC1394_SUCCESS) {
-      *value= DC1394_FALSE;
+    if (dc1394_get_sw_version(handle,node, &version)!=DC1394_SUCCESS) {
+      *value=DC1394_FALSE;
       return DC1394_FAILURE;
     }
     else {
-      quadval&=0xFFFFFFUL;
-    }
-    //fprintf(stderr,"0x%x\n",quadval);
-
-    if ((quadval == 0x000100UL) || 
-        (quadval == 0x000101UL) ||
-        (quadval == 0x000102UL) ||
-        ((quadval == 0x000114UL) && ptgrey) ||
-        ((quadval == 0x800002UL) && ptgrey))
-    {
-        *value= DC1394_TRUE;
-    }
-    else
-    {
-        *value= DC1394_FALSE;
+      if (version!=-1)
+	*value=DC1394_TRUE;
+      else
+	*value=DC1394_FALSE;
     }
 
     return DC1394_SUCCESS;
@@ -1450,7 +1576,7 @@ dc1394_get_camera_feature(raw1394handle_t handle, nodeid_t node,
       feature->one_push= DC1394_FALSE;
       feature->polarity_capable=
 	(value & 0x02000000UL) ? DC1394_TRUE : DC1394_FALSE;
-      feature->trigger_mode_capable_mask= ((value >> 12) & 0x0f);
+      feature->trigger_mode_capable_mask= ((value >> 20) & 0x0f);
       feature->auto_capable= DC1394_FALSE;
       feature->manual_capable= DC1394_FALSE;
       break;
@@ -1615,7 +1741,7 @@ dc1394_print_feature(dc1394_feature_info *f)
 	printf("1 ");
       if (f->trigger_mode_capable_mask & 0x02)
 	printf("2 ");
-      if (f->trigger_mode_capable_mask & 0x02)
+      if (f->trigger_mode_capable_mask & 0x01)
 	printf("3 ");
       if (!(f->trigger_mode_capable_mask & 0x0f))
 	printf("No modes available");
@@ -3293,14 +3419,20 @@ dc1394_get_bandwidth_usage(raw1394handle_t handle, nodeid_t node, unsigned int *
     // get camera ISO speed:
     if (dc1394_get_iso_channel_and_speed(handle, node, &channel, &speed)!= DC1394_SUCCESS)
       return DC1394_FAILURE;
+
+    //fprintf(stderr,"(%s) qpp is %d, speed is %d\n",__FILE__,qpp,speed);
     
     // mutiply by 4 anyway because the best speed is SPEED_400 only
     if (speed>=SPEED_1600)
-      *bandwidth = qpp << (SPEED_1600-speed);
-    else
       *bandwidth = qpp >> (speed-SPEED_1600);
+    else
+      *bandwidth = qpp << (SPEED_1600-speed);
+
+    //fprintf(stderr,"(%s) bandwidth is %d\n",__FILE__, *bandwidth);
+    
   }
   else {
+    //fprintf(stderr,"(%s) iso is off\n",__FILE__);
     *bandwidth=0;
   }
   return DC1394_SUCCESS;
