@@ -159,7 +159,7 @@ enum {
 };
 #define TRIGGER_MODE_MIN            TRIGGER_MODE_0
 #define TRIGGER_MODE_MAX            TRIGGER_MODE_3
-#define NUM_TRIGGER_MODE            (TRIGGER_MODE_3 - TRIGGER_MODE_0 + 1)
+#define NUM_TRIGGER_MODE            (TRIGGER_MODE_MAX - TRIGGER_MODE_MIN + 1)
 
 /* Enumeration of camera image formats */
 enum {
@@ -243,7 +243,7 @@ enum
   IIDC_VERSION_1_38,
   IIDC_VERSION_1_39
 };
-#define IIDC_VERSION_MIN                 IIDC_VERSION_1_02
+#define IIDC_VERSION_MIN                 IIDC_VERSION_1_04
 #define IIDC_VERSION_MAX                 IIDC_VERSION_1_39
 #define NUM_IIDC_VERSION                (IIDC_VERSION_MAX - IIDC_VERSION_MIN + 1)
 
@@ -312,17 +312,17 @@ typedef struct __dc1394_cam_cap_struct
 
 typedef struct __dc1394_misc_info
 {
-  int format;
-  int mode;
-  int framerate;
+  unsigned int format;
+  unsigned int mode;
+  unsigned int framerate;
 
   dc1394bool_t is_iso_on;
-  int iso_channel;
-  int iso_speed;
+  unsigned int iso_channel;
+  unsigned int iso_speed;
 
-  int mem_channel_number;
-  int save_channel;
-  int load_channel;
+  unsigned int mem_channel_number;
+  unsigned int save_channel;
+  unsigned int load_channel;
 
   dc1394bool_t bmode_capable;
   dc1394bool_t one_shot_capable;
@@ -444,6 +444,13 @@ dc1394_print_feature_set(dc1394_feature_set *features);
  system
 
  If a handle can't be created, it returns NULL
+
+ IMPORTANT: you should NOT use raw1394_new_handle()
+ to create a new handle, even if you use
+ raw1394_set_port after. dc1394_create_handle has to
+ setup other things and failing to use it will result
+ in crashes.
+
 *****************************************************/
 raw1394handle_t 
 dc1394_create_handle(int port);
@@ -715,10 +722,6 @@ dc1394_get_frame_rate(raw1394handle_t handle, nodeid_t node,
 int
 dc1394_set_frame_rate(raw1394handle_t handle, nodeid_t node,
 		      unsigned int frame_rate);
-  int
-dc1394_get_hue(raw1394handle_t handle, nodeid_t node,
-	       unsigned int *hue);
-
 int
 dc1394_get_trigger_mode(raw1394handle_t handle, nodeid_t node,
                         unsigned int *mode);
@@ -837,8 +840,8 @@ dc1394_get_max_value(raw1394handle_t handle, nodeid_t node,
 ******************************************************/
 int
 dc1394_dma_setup_capture(raw1394handle_t handle, nodeid_t node,
-                         int channel, int format, int mode,
-                         int speed, int frame_rate, 
+                         unsigned int channel, unsigned int format, unsigned int mode,
+                         unsigned int speed, unsigned int frame_rate, 
                          int num_dma_buffers,
                          int drop_frames,
                          const char *dma_device_file,
@@ -921,8 +924,8 @@ dc1394_dma_done_with_buffer(dc1394_cameracapture * camera);
 ************************************************************/
 int 
 dc1394_setup_capture(raw1394handle_t handle, nodeid_t node, 
-                     int channel, int format, int mode, 
-                     int speed, int frame_rate, 
+                     unsigned int channel, unsigned int format, unsigned int mode, 
+                     unsigned int speed, unsigned int frame_rate, 
                      dc1394_cameracapture * camera);
 
 /***********************************************************
@@ -1059,8 +1062,8 @@ dc1394_get_soft_trigger(raw1394handle_t handle, nodeid_t node,
 /*======================================================================*/
 int
 dc1394_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
-                             int channel, int mode, int speed,
-                             int bytes_per_packet,
+                             unsigned int channel, unsigned int mode, unsigned int speed,
+                             unsigned int bytes_per_packet,
                              unsigned int left, unsigned int top,
                              unsigned int width, unsigned int height, 
                              dc1394_cameracapture * camera);
@@ -1101,8 +1104,8 @@ dc1394_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
 /*======================================================================*/
 int
 dc1394_dma_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
-                                 int channel, int mode, int speed,
-                                 int bytes_per_packet,
+                                 unsigned int channel, unsigned int mode, unsigned int speed,
+                                 unsigned int bytes_per_packet,
                                  unsigned int left, unsigned int top,
                                  unsigned int width, unsigned int height,
                                  int num_dma_buffers,
@@ -1200,11 +1203,6 @@ dc1394_query_format7_packet_per_frame(raw1394handle_t handle, nodeid_t node,
 				      unsigned int mode,
 				      unsigned int *ppf);
 
-int
-dc1394_query_format7_packet_per_frame(raw1394handle_t handle, nodeid_t node,
-				      unsigned int mode,
-				      unsigned int *ppf);
-
 int
 dc1394_query_format7_unit_position(raw1394handle_t handle, nodeid_t node,
 				   unsigned int mode,
