@@ -101,6 +101,8 @@ GetCameraFormat7Register(raw1394handle_t handle, nodeid_t node,
         retval= raw1394_read(handle, 0xffc0 | node,
                              CONFIG_ROM_BASE + csr + offset, 4, value);
 
+	//fprintf(stderr,"got register 0x%llx : 0x%x\n",CONFIG_ROM_BASE + csr + offset,*value);
+
 #ifdef LIBRAW1394_OLD
         if (retval >= 0)
         {
@@ -173,6 +175,7 @@ SetCameraFormat7Register(raw1394handle_t handle, nodeid_t node,
     /* retry a few times if necessary (addition by PDJ) */
     while(retry--)
     {
+      //fprintf(stderr,"trying to set F7 0x%llx\n",offset + csr);
         retval= raw1394_write(handle, 0xffc0 | node,
                               CONFIG_ROM_BASE + offset + csr, 4, &value);
 
@@ -217,7 +220,7 @@ SetCameraFormat7Register(raw1394handle_t handle, nodeid_t node,
 int
 _dc1394_v130_handshake(raw1394handle_t handle, nodeid_t node, int mode)
 {
-  int setting_1, err_flag1, err_flag2, v130handshake;
+  unsigned int setting_1, err_flag1, err_flag2, v130handshake;
   int exit_loop;
 
   dc1394_camerahandle *camera;
@@ -269,7 +272,7 @@ _dc1394_v130_handshake(raw1394handle_t handle, nodeid_t node, int mode)
 int
 _dc1394_v130_errflag2(raw1394handle_t handle, nodeid_t node, int mode)
 {
-  int setting_1, err_flag1, err_flag2, v130handshake;
+  unsigned int setting_1, err_flag1, err_flag2, v130handshake;
 
   dc1394_camerahandle *camera;
   camera = (dc1394_camerahandle*) raw1394_get_userdata( handle );
@@ -343,18 +346,18 @@ _Format7BytePerPixel(int color_coding)
  *======================================================================*/
 int
 _dc1394_basic_format7_setup(raw1394handle_t handle, nodeid_t node,
-                            int channel, int mode, int speed,
-                            int bytes_per_packet,
-                            int left, int top,
-                            int width, int height, 
+                            unsigned int channel, unsigned int mode, unsigned int speed,
+                            unsigned int bytes_per_packet,
+                            unsigned int left, unsigned int top,
+                            unsigned int width, unsigned int height, 
                             dc1394_cameracapture *camera)
 {
   dc1394bool_t is_iso_on= DC1394_FALSE;
   unsigned int unit_bytes, max_bytes;
-  unsigned packet_bytes=0;
+  unsigned int packet_bytes=0;
   unsigned int recom_bpp;
-  int packets_per_frame;
-  int color_coding;
+  unsigned int packets_per_frame;
+  unsigned int color_coding;
   unsigned int camera_left = 0;
   unsigned int camera_top = 0;
   unsigned int camera_width = 0;
@@ -362,6 +365,8 @@ _dc1394_basic_format7_setup(raw1394handle_t handle, nodeid_t node,
   unsigned int max_width = 0;
   unsigned int max_height = 0;
 
+  //fprintf(stderr,"entering setup\n");
+
   dc1394_camerahandle *camerahandle;
   camerahandle = (dc1394_camerahandle*) raw1394_get_userdata( handle );
 
@@ -582,8 +587,8 @@ _dc1394_basic_format7_setup(raw1394handle_t handle, nodeid_t node,
       }
       camera->quadlets_per_frame/=4;
     */
-    //fprintf(stderr,"quadlets per frame: %d\n",camera->quadlets_per_frame);
   }
+  //fprintf(stderr,"quadlets per frame: %d\n",camera->quadlets_per_frame);
 
   if (camera->quadlets_per_frame<=0) {
     return DC1394_FAILURE;
@@ -613,8 +618,8 @@ _dc1394_basic_format7_setup(raw1394handle_t handle, nodeid_t node,
  *=======================================================================*/
 int
 dc1394_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
-                             int channel, int mode, int speed,
-                             int bytes_per_packet,
+                             unsigned int channel, unsigned int mode, unsigned int speed,
+                             unsigned int bytes_per_packet,
                              unsigned int left, unsigned int top,
                              unsigned int width, unsigned int height, 
                              dc1394_cameracapture * camera)
@@ -656,8 +661,8 @@ dc1394_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
  *=======================================================================*/
 int
 dc1394_dma_setup_format7_capture(raw1394handle_t handle, nodeid_t node,
-                                 int channel, int mode, int speed,
-                                 int bytes_per_packet,
+                                 unsigned int channel, unsigned int mode, unsigned int speed,
+                                 unsigned int bytes_per_packet,
                                  unsigned int left, unsigned int top,
                                  unsigned int width, unsigned int height,
                                  int num_dma_buffers,
